@@ -18,11 +18,12 @@
 #'  * A string which indicates the kind of uncertainty estimates to return.
 #'    - Heteroskedasticity-consistent: `"vcovHC"`, `"HC"`, `"HC0"`, `"HC1"`,
 #'      `"HC2"`, `"HC3"`, `"HC4"`, `"HC4m"`, `"HC5"`. See `?sandwich::vcovHC`.
-#'    - Cluster-robust: `"vcovCR"`, `"CR0"`, `"CR1"`, `"CR1p"`, `"CR1S"`, `"CR2"`,
-#'      `"CR3"`. See `?clubSandwich::vcovCR`.
-#'    - Bootstrap: `"vcovBS"`, `"xy"`, `"residual"`, `"wild"`, `"mammen"`, `"webb"`.
-#'      See `?sandwich::vcovBS`.
-#'    - Other `sandwich` package functions: `"vcovHAC"`, `"vcovPC"`, `"vcovCL"`, `"vcovPL"`.
+#'    - Cluster-robust: `"vcovCR"`, `"CR0"`, `"CR1"`, `"CR1p"`, `"CR1S"`,
+#'      `"CR2"`, `"CR3"`. See `?clubSandwich::vcovCR`.
+#'    - Bootstrap: `"vcovBS"`, `"xy"`, `"residual"`, `"wild"`, `"mammen"`,
+#'      `"webb"`. See `?sandwich::vcovBS`.
+#'    - Other `sandwich` package functions: `"vcovHAC"`, `"vcovPC"`, `"vcovCL"`,
+#'      `"vcovPL"`.
 #' @param vcov_args List of arguments to be passed to the function identified by
 #'   the `vcov` argument. This function is typically supplied by the **sandwich**
 #'   or **clubSandwich** packages. Please refer to their documentation (e.g.,
@@ -46,18 +47,18 @@
 #'   standard errors. Depending on the model, may also include columns for model
 #'   components etc.
 #'
-#' @examples
+#' @examplesIf require("sandwich") && require("clubSandwich")
 #' model <- lm(Petal.Length ~ Sepal.Length * Species, data = iris)
 #' standard_error(model)
 #'
-#' if (require("sandwich") && require("clubSandwich")) {
-#'   standard_error(model, vcov = "HC3")
+#' # robust standard errors
+#' standard_error(model, vcov = "HC3")
 #'
-#'   standard_error(model,
-#'     vcov = "vcovCL",
-#'     vcov_args = list(cluster = iris$Species)
-#'   )
-#' }
+#' # cluster-robust standard errors
+#' standard_error(model,
+#'   vcov = "vcovCL",
+#'   vcov_args = list(cluster = iris$Species)
+#' )
 #' @export
 standard_error <- function(model, ...) {
   UseMethod("standard_error")
@@ -81,6 +82,10 @@ standard_error.default <- function(model,
   dots <- list(...)
   se <- NULL
 
+  # if a vcov is provided, we calculate standard errors based on that matrix
+  # this is usually the case for HC (robust) standard errors
+  # ------------------------------------------------------------------------
+
   # vcov: matrix
   if (is.matrix(vcov)) {
     se <- sqrt(diag(vcov))
@@ -88,8 +93,8 @@ standard_error.default <- function(model,
 
   # vcov: function which returns a matrix
   if (is.function(vcov)) {
-    args <- c(list(model), vcov_args, dots)
-    se <- .safe(sqrt(diag(do.call("vcov", args))))
+    fun_args <- c(list(model), vcov_args, dots)
+    se <- .safe(sqrt(diag(do.call("vcov", fun_args))))
   }
 
   # vcov: character (with backward compatibility for `robust = TRUE`)
@@ -105,7 +110,9 @@ standard_error.default <- function(model,
     se <- sqrt(diag(.vcov))
   }
 
-  # classical se from summary()
+  # classical SE from summary()
+  # ------------------------------------------------------------------------
+
   if (is.null(se)) {
     se <- .safe({
       if (grepl("Zelig-", class(model)[1], fixed = TRUE)) {
@@ -116,7 +123,10 @@ standard_error.default <- function(model,
     })
   }
 
-  # classical se from get_varcov()
+  # if retrieving SE from summary() failed, we try to calculate SE based
+  # on classical se from get_varcov()
+  # ------------------------------------------------------------------------
+
   if (is.null(se)) {
     se <- .safe({
       varcov <- insight::get_varcov(model, component = component)
@@ -150,26 +160,27 @@ standard_error.default <- function(model,
 
 
 .get_se_from_summary <- function(model, component = NULL) {
-  cs <- suppressWarnings(stats::coef(summary(model)))
+  cs <- .safe(suppressWarnings(stats::coef(summary(model))))
   se <- NULL
 
-  if (is.list(cs) && !is.null(component)) cs <- cs[[component]]
-
+  if (is.list(cs) && !is.null(component)) {
+    cs <- cs[[component]]
+  }
   if (!is.null(cs)) {
     # do we have a se column?
     se_col <- which(colnames(cs) == "Std. Error")
-
     # if not, default to 2
-    if (length(se_col) == 0) se_col <- 2
-
+    if (length(se_col) == 0) {
+      se_col <- 2
+    }
     se <- as.vector(cs[, se_col])
-
     if (is.null(names(se))) {
       coef_names <- rownames(cs)
-      if (length(coef_names) == length(se)) names(se) <- coef_names
+      if (length(coef_names) == length(se)) {
+        names(se) <- coef_names
+      }
     }
   }
-
   names(se) <- .remove_backticks_from_string(names(se))
   se
 }
