@@ -1,4 +1,3 @@
-#' @rdname model_parameters.averaging
 #' @export
 model_parameters.bfsl <- function(model,
                                   ci = 0.95,
@@ -38,20 +37,3 @@ standard_error.bfsl <- function(model, ...) {
   )
   insight::text_remove_backticks(params, verbose = FALSE)
 }
-
-
-
-#' @export
-degrees_of_freedom.bfsl <- function(model, method = "residual", ...) {
-  if (is.null(method)) {
-    method <- "wald"
-  }
-
-  method <- match.arg(tolower(method), choices = c("analytical", "any", "fit", "wald", "residual", "normal"))
-
-  if (method %in% c("wald", "residual", "fit")) {
-    model$df.residual
-  } else {
-    degrees_of_freedom.default(model, method = method, ...)
-  }
-}
