@@ -1,5 +1,66 @@
 # .fixest -----------------------
 
+#' @export
+model_parameters.fixest <- function(model,
+                                    ci = 0.95,
+                                    ci_method = NULL,
+                                    bootstrap = FALSE,
+                                    iterations = 1000,
+                                    standardize = NULL,
+                                    exponentiate = FALSE,
+                                    p_adjust = NULL,
+                                    summary = getOption("parameters_summary", FALSE),
+                                    keep = NULL,
+                                    drop = NULL,
+                                    verbose = TRUE,
+                                    vcov = NULL,
+                                    vcov_args = NULL,
+                                    ...) {
+  # default ci-method, based on statistic
+  if (is.null(ci_method)) {
+    if (identical(insight::find_statistic(model), "t-statistic")) {
+      ci_method <- "wald"
+    } else {
+      ci_method <- "normal"
+    }
+  }
+
+  # extract model parameters table, as data frame
+  out <- tryCatch(
+    {
+      .model_parameters_generic(
+        model = model,
+        ci = ci,
+        ci_method = ci_method,
+        bootstrap = bootstrap,
+        iterations = iterations,
+        merge_by = "Parameter",
+        standardize = standardize,
+        exponentiate = exponentiate,
+        p_adjust = p_adjust,
+        summary = summary,
+        keep_parameters = keep,
+        drop_parameters = drop,
+        vcov = vcov,
+        vcov_args = vcov_args,
+        verbose = verbose,
+        ...
+      )
+    },
+    error = function(e) {
+      NULL
+    }
+  )
+
+  if (is.null(out)) {
+    insight::format_error("Something went wrong... :-/")
+  }
+
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
+  out
+}
+
+
 #' @export
 standard_error.fixest <- function(model, vcov = NULL, vcov_args = NULL, ...) {
   params <- insight::get_parameters(model)
@@ -21,30 +82,11 @@ standard_error.fixest <- function(model, vcov = NULL, vcov_args = NULL, ...) {
 }
 
 
-#' @export
-degrees_of_freedom.fixest <- function(model, method = "wald", ...) {
-  # fixest degrees of freedom can be tricky. best to use the function by the
-  # package.
-  insight::check_if_installed("fixest")
-  if (is.null(method)) {
-    method <- "wald"
-  }
-  method <- match.arg(
-    tolower(method),
-    choices = c("wald", "residual")
-  )
-  method <- switch(method,
-    "wald" = "t",
-    "residual" = "resid"
-  )
-  fixest::degrees_freedom(model, type = method)
-}
-
-
-
-
 # .feglm -----------------------
 
+#' @export
+model_parameters.feglm <- model_parameters.fixest
+
 #' @export
 standard_error.feglm <- function(model, ...) {
   stats <- stats::coef(summary(model))
@@ -156,22 +198,6 @@ standard_error.fixest_multi <- function(model, ...) {
 }
 
 
-#' @export
-degrees_of_freedom.fixest_multi <- function(model, ...) {
-  out <- do.call(rbind, lapply(model, degrees_of_freedom, ...))
-
-  # add response and group columns
-  id_columns <- .get_fixest_multi_columns(model)
-
-  # add response column
-  out$Response <- id_columns$Response
-  out$Group <- id_columns$Group
-
-  row.names(out) <- NULL
-  out
-}
-
-
 #' @export
 p_value.fixest_multi <- function(model, ...) {
   out <- do.call(rbind, lapply(model, p_value, ...))
