@@ -5,6 +5,8 @@ model_parameters.mhurdle <- function(model,
                                      component = c("all", "conditional", "zi", "zero_inflated", "infrequent_purchase", "ip", "auxiliary"),
                                      exponentiate = FALSE,
                                      p_adjust = NULL,
+                                     keep = NULL,
+                                     drop = NULL,
                                      verbose = TRUE,
                                      ...) {
   component <- match.arg(component)
@@ -17,12 +19,14 @@ model_parameters.mhurdle <- function(model,
     effects = "fixed",
     component = component,
     p_adjust = p_adjust,
+    keep_parameters = keep,
+    drop_parameters = drop,
     verbose = verbose,
     ...
   )
   params$Parameter <- gsub("^(h1|h2|h3)\\.(.*)", "\\2", params$Parameter)
 
-  attr(params, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(params, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   params
 }
 
@@ -57,12 +61,6 @@ ci.mhurdle <- function(x, ci = 0.95, ...) {
 }
 
 
-#' @export
-degrees_of_freedom.mhurdle <- function(model, method = NULL, ...) {
-  .degrees_of_freedom_no_dfresid_method(model, method)
-}
-
-
 #' @export
 standard_error.mhurdle <- function(model, component = c("all", "conditional", "zi", "zero_inflated", "infrequent_purchase", "ip", "auxiliary"), ...) {
   component <- match.arg(component)
@@ -93,6 +91,6 @@ simulate_model.mhurdle <- function(model, iterations = 1000, component = c("all"
   out <- .simulate_model(model, iterations, component = component, effects = "fixed", ...)
 
   class(out) <- c("parameters_simulate_model", class(out))
-  attr(out, "object_name") <- insight::safe_deparse(substitute(model))
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   out
 }
