@@ -33,7 +33,6 @@ model_parameters.systemfit <- function(model,
 }
 
 
-
 #' @export
 standard_error.systemfit <- function(model, ...) {
   cf <- stats::coef(summary(model))
@@ -57,7 +56,6 @@ standard_error.systemfit <- function(model, ...) {
 }
 
 
-
 #' @export
 p_value.systemfit <- function(model, ...) {
   cf <- stats::coef(summary(model))
@@ -81,25 +79,5 @@ p_value.systemfit <- function(model, ...) {
 }
 
 
-
-#' @export
-degrees_of_freedom.systemfit <- function(model, ...) {
-  df <- NULL
-  s <- summary(model)$eq
-  params <- insight::find_parameters(model)
-  f <- insight::find_formula(model)
-  system_names <- names(f)
-
-  for (i in seq_along(system_names)) {
-    dfs <- rep(s[[i]]$df[2], length(params[[i]]))
-    df_names <- rep(names(params[i]), length(params[[i]]))
-    df <- c(df, stats::setNames(dfs, df_names))
-  }
-
-  df
-}
-
-
-
 #' @export
 ci.systemfit <- ci.lm
