@@ -1,6 +1,6 @@
 # small wrapper around this commonly used try-catch
 .safe <- function(code, on_error = NULL) {
-  if (getOption("easystats_erros", FALSE) && is.null(on_error)) {
+  if (isTRUE(getOption("easystats_errors", FALSE)) && is.null(on_error)) {
     code
   } else {
     tryCatch(code, error = function(e) on_error)
