@@ -7,7 +7,7 @@
 # default method -------------------
 
 .extract_random_variances.default <- function(model,
-                                              ci = .95,
+                                              ci = 0.95,
                                               effects = "random",
                                               component = "conditional",
                                               ci_method = NULL,
@@ -26,12 +26,10 @@
   )
 
   # check for errors
-  if (is.null(out)) {
-    if (isTRUE(verbose)) {
-      insight::format_warning(
-        "Something went wrong when calculating random effects parameters. Only showing model's fixed effects now. You may use `effects=\"fixed\"` to speed up the call to `model_parameters()`."
-      )
-    }
+  if (is.null(out) && isTRUE(verbose)) {
+    insight::format_warning(
+      "Something went wrong when calculating random effects parameters. Only showing model's fixed effects now. You may use `effects=\"fixed\"` to speed up the call to `model_parameters()`."
+    )
   }
 
   out
@@ -41,7 +39,7 @@
 # glmmTMB -------------------
 
 .extract_random_variances.glmmTMB <- function(model,
-                                              ci = .95,
+                                              ci = 0.95,
                                               effects = "random",
                                               component = "all",
                                               ci_method = NULL,
@@ -115,7 +113,7 @@
 # workhorse ------------------------
 
 .extract_random_variances_helper <- function(model,
-                                             ci = .95,
+                                             ci = 0.95,
                                              effects = "random",
                                              component = "conditional",
                                              ci_method = NULL,
@@ -123,22 +121,10 @@
                                              ...) {
   varcorr <- .get_variance_information(model, component)
 
-  ran_intercept <- tryCatch(data.frame(.random_intercept_variance(varcorr)),
-    error = function(e) NULL
-  )
-
-  ran_slope <- tryCatch(data.frame(.random_slope_variance(model, varcorr)),
-    error = function(e) NULL
-  )
-
-  ran_corr <- tryCatch(data.frame(.random_slope_intercept_corr(model, varcorr)),
-    error = function(e) NULL
-  )
-
-  ran_slopes_corr <- tryCatch(data.frame(.random_slopes_corr(model, varcorr)),
-    error = function(e) NULL
-  )
-
+  ran_intercept <- .safe(data.frame(.random_intercept_variance(varcorr)))
+  ran_slope <- .safe(data.frame(.random_slope_variance(model, varcorr)))
+  ran_corr <- .safe(data.frame(.random_slope_intercept_corr(model, varcorr)))
+  ran_slopes_corr <- .safe(data.frame(.random_slopes_corr(model, varcorr)))
 
   # sigma/dispersion only once,
   if (component == "conditional") {
@@ -316,7 +302,7 @@
 
 .random_sd_ci <- function(model, out, ci_method, ci, corr_param, sigma_param, component = NULL, verbose = FALSE) {
   ## TODO needs to be removed once MCM > 0.1.5 is on CRAN
-  if (grepl("^mcm_lmer", insight::safe_deparse(insight::get_call(model)))) {
+  if (startsWith(insight::safe_deparse(insight::get_call(model)), "mcm_lmer")) {
     return(out)
   }
 
@@ -331,7 +317,7 @@
       rn <- gsub("[\\(\\)]", "", rn)
       rn <- gsub("cor_(.*)\\.(.*)", "cor \\2", rn)
 
-      var_ci_corr_param <- grepl("^cor ", rn)
+      var_ci_corr_param <- startsWith(rn, "cor ")
       var_ci_sigma_param <- rn == "sigma"
 
       out$CI_low[!corr_param & !sigma_param] <- var_ci$CI_low[!var_ci_corr_param & !var_ci_sigma_param]
@@ -434,8 +420,8 @@
             if (any(var_ci_corr_param)) {
               coefs <- out$Coefficient[var_ci_corr_param]
               delta_se <- out$SE[var_ci_corr_param] / (1 - coefs^2)
-              out$CI_low[var_ci_corr_param] <- tanh(atanh(coefs) - stats::qnorm(.975) * delta_se)
-              out$CI_high[var_ci_corr_param] <- tanh(atanh(coefs) + stats::qnorm(.975) * delta_se)
+              out$CI_low[var_ci_corr_param] <- tanh(atanh(coefs) - stats::qnorm(0.975) * delta_se)
+              out$CI_high[var_ci_corr_param] <- tanh(atanh(coefs) + stats::qnorm(0.975) * delta_se)
             }
 
             # Wald CI, based on delta-method.
@@ -444,8 +430,8 @@
             # Also, if the SD is small, then the CI might go negative
             coefs <- out$Coefficient[!var_ci_corr_param]
             delta_se <- out$SE[!var_ci_corr_param] / coefs
-            out$CI_low[!var_ci_corr_param] <- exp(log(coefs) - stats::qnorm(.975) * delta_se)
-            out$CI_high[!var_ci_corr_param] <- exp(log(coefs) + stats::qnorm(.975) * delta_se)
+            out$CI_low[!var_ci_corr_param] <- exp(log(coefs) - stats::qnorm(0.975) * delta_se)
+            out$CI_high[!var_ci_corr_param] <- exp(log(coefs) + stats::qnorm(0.975) * delta_se)
 
             # warn if singular fit
             if (isTRUE(verbose) && insight::check_if_installed("performance", quietly = TRUE) && isTRUE(performance::check_singularity(model))) {
@@ -688,17 +674,20 @@
       attr(vc2, "correlation") <- stats::cov2cor(model$D[vc_zi, vc_zi, drop = FALSE])
     }
 
+    model_deviance <- insight::get_deviance(model, verbose = FALSE)
+    residual_df <- insight::get_df(model, type = "residual", verbose = FALSE)
+
     vc1 <- list(vc1)
     names(vc1) <- re_names[[1]]
-    attr(vc1, "sc") <- sqrt(insight::get_deviance(model, verbose = FALSE) / insight::get_df(model, type = "residual", verbose = FALSE))
+    attr(vc1, "sc") <- sqrt(abs(model_deviance) / residual_df)
 
     if (!is.null(vc2)) {
       vc2 <- list(vc2)
       names(vc2) <- re_names[[2]]
-      attr(vc2, "sc") <- sqrt(insight::get_deviance(model, verbose = FALSE) / insight::get_df(model, type = "residual", verbose = FALSE))
+      attr(vc2, "sc") <- sqrt(abs(model_deviance) / residual_df)
     }
 
-    varcorr <- datawizard::compact_list(list(vc1, vc2))
+    varcorr <- insight::compact_list(list(vc1, vc2))
     names(varcorr) <- c("cond", "zi")[seq_along(varcorr)]
 
     # joineRML
@@ -712,7 +701,7 @@
     names(varcorr) <- re_names[1]
     attr(varcorr, "sc") <- model$coef$sigma2[[1]]
 
-    # nlme
+    # nlme / glmmPQL
     # ---------------------------
   } else if (inherits(model, "lme")) {
     re_names <- insight::find_random(model, split_nested = TRUE, flatten = TRUE)
@@ -752,7 +741,7 @@
       }
       out
     })
-    varcorr <- datawizard::compact_list(varcorr)
+    varcorr <- insight::compact_list(varcorr)
     names(varcorr) <- setdiff(names(lme4::VarCorr(model)), "residual__")
     attr(varcorr, "sc") <- lme4::VarCorr(model)$residual__$sd[1, 1]
 
@@ -801,7 +790,7 @@
 
   names(vc_list) <- re_names
 
-  mapply(
+  Map(
     function(x, y) {
       if ("Corr" %in% colnames(x)) {
         g_cor <- suppressWarnings(stats::na.omit(as.numeric(x[, "Corr"])))
@@ -827,8 +816,7 @@
       m1
     },
     vc_list,
-    vc_rownames,
-    SIMPLIFY = FALSE
+    vc_rownames
   )
 }
 
@@ -881,7 +869,7 @@
     non_intercepts <- which(sapply(varcorr, function(i) !startsWith(dimnames(i)[[1]][1], "(Intercept)")))
     if (length(non_intercepts)) {
       if (length(non_intercepts) == length(varcorr)) {
-        out <- unlist(lapply(varcorr, function(x) diag(x)))
+        out <- unlist(lapply(varcorr, diag))
       } else {
         dn <- unlist(lapply(varcorr, function(i) dimnames(i)[1])[non_intercepts])
         rndslopes <- unlist(lapply(varcorr, function(i) {
@@ -897,14 +885,14 @@
         # anything missing? (i.e. correlated slope-intercept slopes)
         missig_rnd_slope <- setdiff(names(out), names(rndslopes))
         if (length(missig_rnd_slope)) {
-          # sanity check
+          # validation check
           to_remove <- c()
           for (j in seq_along(out)) {
             # identical random slopes might have different names, so
             # we here check if random slopes from correlated and uncorrelated
             # are duplicated (i.e. their difference is 0 - including a tolerance)
             # and then remove duplicated elements
-            the_same <- which(abs(outer(out[j], rndslopes, `-`)) < .0001)
+            the_same <- which(abs(outer(out[j], rndslopes, `-`)) < 0.0001)
             if (length(the_same) && grepl(dn[the_same], names(out[j]), fixed = TRUE)) {
               to_remove <- c(to_remove, j)
             }
@@ -944,7 +932,7 @@
 # ----------------------------------------------
 .random_slope_intercept_corr <- function(model, varcorr) {
   if (inherits(model, "lme")) {
-    rho01 <- unlist(sapply(varcorr, function(i) attr(i, "cor_slope_intercept")))
+    rho01 <- unlist(sapply(varcorr, attr, which = "cor_slope_intercept"))
     if (is.null(rho01)) {
       vc <- lme4::VarCorr(model)
       if ("Corr" %in% colnames(vc)) {
@@ -957,7 +945,7 @@
     }
     rho01
   } else {
-    corrs <- lapply(varcorr, attr, "correlation")
+    corrs <- lapply(varcorr, attr, which = "correlation")
     rho01 <- sapply(corrs, function(i) {
       if (!is.null(i) && colnames(i)[1] == "(Intercept)") {
         i[-1, 1]
@@ -982,7 +970,7 @@
   cat_random_slopes <- tryCatch(
     {
       d <- insight::get_data(model)[rnd_slopes]
-      any(sapply(d, is.factor))
+      any(vapply(d, is.factor, TRUE))
     },
     error = function(e) {
       NULL
